==> haskell-microstache-1.0.1.1-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microstache
version: 1.0.1.1
id: microstache-1.0.1.1-CgsmLP2ndTG9QxR0QyqsRb
key: microstache-1.0.1.1-CgsmLP2ndTG9QxR0QyqsRb
license: BSD-3-Clause
maintainer: Oleg Grenrus<oleg.grenrus@iki.fi>
author: Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/microstache
synopsis: Mustache templates for Haskell
description:
    Mustache templates for Haskell.
    .
    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.
category: Text
abi: b224f4f2ca309150864c2541bad2adf8
exposed: True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type
import-dirs: /usr/lib/ghc-8.4.3/site-local/microstache-1.0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/microstache-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/microstache-1.0.1.1
hs-libraries: HSmicrostache-1.0.1.1-CgsmLP2ndTG9QxR0QyqsRb
depends:
    aeson-1.3.1.1-J1bdggn8TZj5jjcHYxM7mi base-4.11.1.0
    bytestring-0.10.8.2 containers-0.5.11.0 deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2 parsec-3.1.13.0
    transformers-0.5.5.0 text-1.2.3.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: aeson-1.3.1.1-J1bdggn8TZj5jjcHYxM7mi=4bd33a472ed49d1f25a046c18b4acb2d
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html: /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microstache-1.0.1.1-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microstache
version: 1.0.1.1
id: microstache-1.0.1.1-39jst4dTnM7HZlr2Vo4Bol
key: microstache-1.0.1.1-39jst4dTnM7HZlr2Vo4Bol
license: BSD-3-Clause
maintainer: Oleg Grenrus<oleg.grenrus@iki.fi>
author: Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/microstache
synopsis: Mustache templates for Haskell
description:
    Mustache templates for Haskell.
    .
    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.
category: Text
abi: 2e31d6a8a38cae016ffbea6c15828b5d
exposed: True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type
import-dirs: /usr/lib/ghc-8.4.3/site-local/microstache-1.0.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/microstache-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/microstache-1.0.1.1
hs-libraries: HSmicrostache-1.0.1.1-39jst4dTnM7HZlr2Vo4Bol
depends:
    aeson-1.3.1.1-1nEmepS46wy5uGcqqGhuZh base-4.11.1.0
    bytestring-0.10.8.2 containers-0.5.11.0 deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2 parsec-3.1.13.0
    transformers-0.5.5.0 text-1.2.3.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: aeson-1.3.1.1-1nEmepS46wy5uGcqqGhuZh=c287354ad2648dab0b3d1c674c591b00
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html: /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
